User Guide - Nautobot Documentation

Skip to content

# User Guide Overview

Welcome to the Nautobot User Guide! The User Guide is designed to help you setup, use, and operate your Nautobot installation.

There are four main headings within the User Guide:

- Administration: Get detailed instructions on installation, migration, configuration, and upgrading Nautobot.
- Feature Guides: Walk through these guides if you are a new user to Nautobot and wondering how to perform common tasks in the Web UI.
- Core Data Model: Read about all the Nautobot data models used to store your network data.
- Platform Functionality: Dive deep into Nautobot extensibility, such as building automation with Jobs, programmatically accessing data through the REST and GraphQL APIs, or using Git repositories as a data source.

## Quick Links

Tip

Are you a new user to Nautobot looking to get started? Explore the following resources.

- Installing Nautobot

  Get started with Nautobot installation on your own Linux Platform or in a Docker environment.

- Using Nautobot

  Dive into how to use Nautobot and the key components of the core web interface.

- Migrating to Nautobot

  Dig into how you can migrate from NetBox to Nautobot seamlessly.

- New User Resources

  Take advantage of the Nautobot Navigators collection of curated resources, including eBooks and a guided Nautobot Sandbox tour.

Tip

Already familiar with Nautobot and looking to expand your knowledge? Check out these advanced topics.

- Nautobot APIs

  Check out the REST API documentation covering both basic features and advanced use cases.

  Are you looking for GraphQL APIs instead? If you are new to GraphQL, you can also read the Nautobot GraphQL User Guide.

- Jobs

  Looking to run your custom Python code on demand?

  Explore Nautobot Jobs, which leverage your Nautobot data to automate using your Python code.

- Nautobot & NAPALM

  Are you curious how NAPALM integrates with Nautobot? Learn how you can use NAPALM functionality to fetch live data from network devices.

- Nautobot Apps & Solutions

  Discover the power of Nautobot Apps & Solutions, from the Golden Configuration app enforcing configuration compliance to the SSoT app synchronizing data across multiple sources of truth.

  These apps are all open source and commercially supported by Network to Code.